@@ -37,10 +37,10 @@ AppMenuView::AppMenuView(QWidget* parent):
 
     // initialize model
     // TODO: share one model among all app menu view widgets
-    // ensure that we're using lxmenu-data (FIXME: should we do this?)
+    // ensure that we're using the fm menu of lxqt-menu-data
     QByteArray oldenv = qgetenv("XDG_MENU_PREFIX");
-    qputenv("XDG_MENU_PREFIX", "lxde-");
-    menu_cache = menu_cache_lookup("applications.menu");
+    qputenv("XDG_MENU_PREFIX", "lxqt-");
+    menu_cache = menu_cache_lookup("applications-fm.menu");
     // if(!oldenv.isEmpty())
     qputenv("XDG_MENU_PREFIX", oldenv); // restore the original value if needed
 
@@ -67,6 +67,11 @@ AppMenuView::~AppMenuView() {
     }
 }
 
+// To avoid incompatible cast to GDestroyNotify:
+static inline void menu_cache_item_unref0(MenuCacheItem* item) {
+    menu_cache_item_unref(item);
+}
+
 void AppMenuView::addMenuItems(QStandardItem* parentItem, MenuCacheDir* dir) {
     GSList* l;
     GSList* list;
@@ -95,7 +100,7 @@ void AppMenuView::addMenuItems(QStandardItem* parentItem, MenuCacheDir* dir) {
         }
         }
     }
-    g_slist_free_full(list, (GDestroyNotify)menu_cache_item_unref);
+    g_slist_free_full(list, (GDestroyNotify)menu_cache_item_unref0);
 }
 
 void AppMenuView::onMenuCacheReload(MenuCache* mc) {
