@@ -238,7 +238,15 @@ void PlacesView::activateRow(int type, const QModelIndex& index) {
                     QTimer::singleShot(0, op, [this, op, type, index] () {
                         if(op->wait()) {
                             if(PlacesModelItem* item = static_cast<PlacesModelItem*>(model_->itemFromIndex(proxyModel_->mapToSource(index)))) {
-                                if(auto path = item->path()) {
+                                auto path = item->path();
+                                if(!path && item->type() == PlacesModelItem::Volume) {
+                                    // If the signal "mount-added" is not emitted at this moment,
+                                    // the path is not set yet. Try to update the item.
+                                    auto volumeItem = static_cast<PlacesModelVolumeItem*>(item);
+                                    volumeItem->update();
+                                    path = volumeItem->path();
+                                }
+                                if(path) {
                                     Q_EMIT chdirRequested(type, path);
                                 }
                             }
@@ -571,7 +579,7 @@ void PlacesView::contextMenuEvent(QContextMenuEvent* event) {
                 if(strcmp(path_str.get(), "trash:///") == 0) {
                     action = new PlacesModel::ItemAction(item->index(), tr("Empty Trash"), menu);
                     auto icn = item->icon();
-                    if(icn && icn->qicon().name() == QLatin1String("user-trash")) { // surely an empty trash
+                    if(icn && icn->qicon().name() == QLatin1StringView("user-trash")) { // surely an empty trash
                         action->setEnabled(false);
                     }
                     else {
