@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 2017  Hong Jen Yee (PCMan) <pcman.tw@gmail.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ */
 #include <QApplication>
 #include <QMainWindow>
 #include <QToolBar>
@@ -33,9 +51,9 @@ int main(int argc, char** argv) {
     QToolBar toolbar;
     win.addToolBar(Qt::TopToolBarArea, &toolbar);
     Fm::PathEdit edit;
-    edit.setText(home.toString().get());
+    edit.setText(QString::fromUtf8(home.toString().get()));
     toolbar.addWidget(&edit);
-    auto action = new QAction("Go", nullptr);
+    auto action = new QAction(QStringLiteral("Go"), nullptr);
     toolbar.addAction(action);
     QObject::connect(action, &QAction::triggered, [&]() {
         auto path = Fm::FilePath::fromPathStr(edit.text().toLocal8Bit().constData());
